@@ -37,6 +37,8 @@ OC.L10N.register(
     "Accept" : "Asantiñ",
     "Remove" : "Lemel",
     "email" : "postel",
+    "Today" : "Hiziv",
+    "Yesterday" : "Dec'h",
     "Choose target folder" : "Dibab an teuliad moned",
     "Important info" : "Titouroù pouezus",
     "Other" : "All",
@@ -67,10 +69,11 @@ OC.L10N.register(
     "Port" : "Porzh",
     "Valid until" : "Gwir betek",
     "Submit" : "Kinnig",
+    "Shared" : "Rannet",
+    "Shares" : "Rannañ",
     "Account connected" : "Kont kenstaged",
     "All" : "Pep tra",
     "Favorites" : "Pennrolloù",
-    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
-    "Actions" : "Oberoù"
+    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
