@@ -59,6 +59,7 @@ OC.L10N.register(
     "Search" : "Serĉi",
     "Send" : "Sendi",
     "Refresh" : "Aktualigi",
+    "Ok" : "Bone",
     "From" : "De",
     "Select account" : "Elekti konton",
     "To" : "Al",
@@ -88,6 +89,7 @@ OC.L10N.register(
     "Report this bug" : "Raporti tiun problemon",
     "Could not create event" : "Ne eblis krei okazaĵon",
     "All day" : "Tuttage",
+    "Attendees" : "Ĉeestontoj",
     "Description" : "Priskribo",
     "Create" : "Krei",
     "Select" : "Elekti",
@@ -96,6 +98,7 @@ OC.L10N.register(
     "Decline" : "Malakcepti",
     "Remove" : "Forigi",
     "email" : "retpoŝtadreso",
+    "Today" : "Hodiaŭ",
     "Choose target folder" : "Elekti celan dosierujon",
     "Other" : "Alia",
     "Forward" : "Antaŭen",
@@ -172,6 +175,9 @@ OC.L10N.register(
     "Valid until" : "Valida ĝis",
     "Certificate" : "Atestilo",
     "Submit" : "Sendi",
+    "Group" : "Grupo",
+    "Shared" : "Kunhavigita",
+    "Shares" : "Kunhavoj",
     "Account connected" : "Konto konektita",
     "Connect your mail account" : "Konekti vian retpoŝtan konton",
     "All" : "Ĉiuj",
@@ -195,10 +201,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Alklaku ĉi tie, ĉu vi ne estos aŭtomate alidirektita post kelkaj sekundoj.",
     "Redirect" : "Alidirekto",
     "The link leads to %s" : "La ligilo iras al %s",
-    "Continue to %s" : "Daŭrigi al %s",
-    "Draft: " : "Malneto:",
-    "Could not open mailbox" : "Ne eblis malfermi poŝtkesto",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksas viajn mesaĝojn. Tio eble daŭrus iom pli longe por pli grandaj poŝtkestoj.",
-    "Actions" : "Agoj"
+    "Continue to %s" : "Daŭrigi al %s"
 },
 "nplurals=2; plural=(n != 1);");
