@@ -26,6 +26,7 @@ OC.L10N.register(
     "General" : "Umum",
     "List" : "Daftar",
     "Register" : "Daftar",
+    "Shared with me" : "Dibagikan dengan saya",
     "About" : "Tentang",
     "Keyboard shortcuts" : "Pintasan keyboard",
     "Archive" : "Arsip",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "Search" : "Cari",
     "Send" : "Kirim",
     "Refresh" : "Segarkan",
+    "Ok" : "Oke",
     "Subject" : "Subjek",
     "Upload attachment" : "Unggah lampiran",
     "Choose" : "Pilih",
@@ -42,8 +44,11 @@ OC.L10N.register(
     "Read" : "Baca",
     "Edit tags" : "Sunting label",
     "Back" : "Kembali",
+    "Mark as unread" : "Tandai belum dibaca",
+    "Mark as read" : "tandai sudah dibaca",
     "Create event" : "Buat acara",
     "All day" : "Sepanjang hari",
+    "Attendees" : "Peserta",
     "Description" : "Deskrisi",
     "Create" : "Buat",
     "Select" : "Pilih",
@@ -52,6 +57,9 @@ OC.L10N.register(
     "Decline" : "Tolak",
     "Remove" : "Buang",
     "email" : "email",
+    "Today" : "Hari ini",
+    "Last week" : "Minggu lalu",
+    "Last month" : "Bulan lalu",
     "Choose target folder" : "Pilih folder target",
     "Other" : "Lainnya",
     "Forward" : "Teruskan",
@@ -60,11 +68,10 @@ OC.L10N.register(
     "Import into calendar" : "Impor ke kalender",
     "Download attachment" : "Unduh lampiran",
     "Move" : "Pindah",
-    "Loading …" : "Memuat …",
     "Remove account" : "Hapus akun",
-    "Quota" : "Kuota",
     "Folder name" : "Nama folder",
     "Saving" : "Menyimpan",
+    "Loading …" : "Memuat …",
     "Mark all as read" : "Tandai semua telah dibaca",
     "Rename" : "Ubah nama",
     "Clear cache" : "Bersihkan cache",
@@ -84,8 +91,6 @@ OC.L10N.register(
     "Tag already exists" : "Tag sudah ada",
     "Add tag" : "Tambahkan tag",
     "Unsubscribe" : "Berhenti berlangganan",
-    "Mark as unread" : "Tandai belum dibaca",
-    "Mark as read" : "tandai sudah dibaca",
     "Untitled event" : "Acara tanpa judul",
     "(organizer)" : "(penyelenggara)",
     "Recipient" : "Penerima",
@@ -101,6 +106,10 @@ OC.L10N.register(
     "Port" : "Port",
     "Valid until" : "Berlaku sampai",
     "Certificate" : "Sertifikat",
+    "Guest" : "Tamu",
+    "Group" : "Grup",
+    "Shared" : "Dibagikan",
+    "Shares" : "Dibagikan",
     "Account connected" : "Akun terhubung",
     "Connect your mail account" : "Hubungkan akun email Anda",
     "All" : "Semua",
@@ -116,7 +125,6 @@ OC.L10N.register(
     "Error loading message" : "Terjadi kesalahan saat memuat pesan",
     "Forwarding to %s" : "Teruskan ke %s",
     "Redirect" : "Mengalihkan",
-    "Continue to %s" : "Lanjutkan ke %s",
-    "Actions" : "Tindakan"
+    "Continue to %s" : "Lanjutkan ke %s"
 },
 "nplurals=1; plural=0;");
