@@ -4,6 +4,7 @@ OC.L10N.register(
     "Personal" : "Udmawan",
     "Mail" : "Tirawt",
     "Save" : "Sekles",
+    "Connect" : "Qqen",
     "Name" : "Nom",
     "Password" : "Awal uffir",
     "None" : "Ula d yiwen",
@@ -11,6 +12,7 @@ OC.L10N.register(
     "Cancel" : "Sefsex",
     "Accounts" : "Imiḍanen",
     "General" : "Amatu",
+    "List" : "Tabdart",
     "About" : "Γef",
     "Delete" : "Kkes",
     "Search" : "Nadi",
@@ -40,13 +42,17 @@ OC.L10N.register(
     "Copy to clipboard" : "Copier dans le presse-papiers",
     "Add" : "Rnu",
     "Close" : "Mdel",
+    "Date" : "Azemz",
     "Tags" : "Tibzimin",
+    "Translate from" : "Suqel seg",
+    "Translate to" : "Suqel ar",
     "User" : "Aseqdac",
     "Guest" : "Inebgi",
     "Group" : "Agraw",
     "All" : "Akk",
     "Favorites" : "Imenyafen",
     "Inbox" : "Tanaka",
+    "Nextcloud Mail" : "Imayl n Nextcloud",
     "Message sent" : "Izen yettwazen"
 },
 "nplurals=2; plural=(n != 1);");
