@@ -220,7 +220,7 @@ OC.L10N.register(
     "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Означи {number} како неважна","Означи {number} како неважни"],
     "_Unselect {number}_::_Unselect {number}_" : ["Од-означи {number}","Од-означи {number}"],
     "_Mark {number} as spam_::_Mark {number} as spam_" : ["Означи {number} како спам","Означи {number} како спам"],
-    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Препрати како прилог","Препрати {number} како прилозиt"],
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Препрати како {number} прилог","Препрати {number} како прилози"],
     "Mark as unread" : "Означи како непрочитано",
     "Mark as read" : "Означи како прочитано",
     "Report this bug" : "Пријави грешка",
@@ -230,6 +230,7 @@ OC.L10N.register(
     "All day" : "Цели денови",
     "Attendees" : "Присутни",
     "Select calendar" : "Избери календар",
+    "Description" : "Опис",
     "Create" : "Креирај",
     "This event was updated" : "Овој настан беше ажуриран",
     "{attendeeName} accepted your invitation" : "{attendeeName} ја прифати вашата покана",
