@@ -19,17 +19,20 @@ OC.L10N.register(
     "Search" : "Search",
     "Send" : "Send",
     "Refresh" : "Last inn på nytt",
+    "Ok" : "Greitt",
     "Choose" : "Vel",
     "Favorite" : "Favoritt",
     "Back" : "Tilbake",
+    "Attendees" : "Deltakarar",
     "Description" : "Skildring",
     "Create" : "Lag",
     "Select" : "Vel",
     "Comment" : "Kommentér",
     "Remove" : "Fjern",
+    "Today" : "I dag",
+    "Yesterday" : "I går",
     "Other" : "Anna",
     "Move" : "Move",
-    "Quota" : "Kvote",
     "Folder name" : "Katalognavn",
     "Saving" : "Lagrar",
     "Rename" : "Endra namn",
@@ -46,10 +49,13 @@ OC.L10N.register(
     "Host" : "Tenar",
     "Port" : "Port",
     "Certificate" : "Sertifikat",
+    "Guest" : "Gjest",
+    "Group" : "Gruppe",
+    "Shared" : "Delt",
+    "Shares" : "Delingar",
     "All" : "Alle",
     "Favorites" : "Favorit",
     "Sent" : "Sendt",
-    "Message sent" : "Melding sendt",
-    "Actions" : "Handlingar"
+    "Message sent" : "Melding sendt"
 },
 "nplurals=2; plural=(n != 1);");
