@@ -52,7 +52,10 @@ OC.L10N.register(
     "Read" : "Legit",
     "More actions" : "Mai d’accions",
     "Back" : "Retorn",
+    "Mark as unread" : "Marcar coma pas legit",
+    "Mark as read" : "Marcar coma legit",
     "All day" : "Tota la jornada",
+    "Attendees" : "Convidats",
     "Description" : "Descripcion",
     "Create" : "Crear",
     "Select" : "Select",
@@ -84,8 +87,6 @@ OC.L10N.register(
     "Date" : "Data",
     "Tags" : "Etiquetas",
     "Custom" : "Personalizats",
-    "Mark as unread" : "Marcar coma pas legit",
-    "Mark as read" : "Marcar coma legit",
     "Translate message" : "Traduire lo messatge",
     "Translating" : "Traduccion",
     "Untitled event" : "Eveniment sens títol",
@@ -116,7 +117,6 @@ OC.L10N.register(
     "{from}\n{subject}" : "{from}\n{subject}",
     "Message sent" : "Messatge mandat",
     "Error loading message" : "Error al moment del cargament del messatge",
-    "Continue to %s" : "Contunhar cap a %s",
-    "Actions" : "Accions"
+    "Continue to %s" : "Contunhar cap a %s"
 },
 "nplurals=2; plural=(n > 1);");
