@@ -30,11 +30,12 @@ OC.L10N.register(
     "Accept" : "පිළිගන්න",
     "Decline" : "ප්‍රතික්ෂේප",
     "Remove" : "ඉවත් කරන්න",
+    "Today" : "අද",
     "Other" : "වෙනත්",
     "Translate" : "පරිවර්තනය",
-    "Loading …" : "පූරණය වෙමින් …",
     "Remove account" : "ගිණුම ඉවත් කරන්න",
     "Folder name" : "බහාලුමේ නම",
+    "Loading …" : "පූරණය වෙමින් …",
     "Mark all as read" : "සියල්ල කියවූ ලෙස සලකුණු කරන්න",
     "Reply" : "පිළිතුර",
     "Retry" : "නැවත උත්සාහ කරන්න",
@@ -47,8 +48,8 @@ OC.L10N.register(
     "User" : "පරිශීලක",
     "Host" : " ධාරකය",
     "Certificate" : "සහතිකය",
+    "Shares" : "බෙදාගැනීම්",
     "All" : "සියල්ල",
-    "Favorites" : "ප්‍රියතම",
-    "Actions" : "ක්‍රියාමාර්ග"
+    "Favorites" : "ප්‍රියතම"
 },
 "nplurals=2; plural=(n != 1);");
