@@ -23,6 +23,7 @@ OC.L10N.register(
     "General" : "Kuu",
     "Layout" : "Mpangilio",
     "List" : "Orodha",
+    "Sorting" : "Sorting",
     "Register" : "Sajiri",
     "About" : "Kuhusu",
     "Keyboard shortcuts" : "Mikato ya keyboard",
@@ -84,10 +85,13 @@ OC.L10N.register(
     "Remove {email}" : "Remove {email}",
     "Add folder" : "Ongeza kisanduku",
     "Folder name" : "Jina la kisanduku",
+    "Move up" : "Move up",
+    "Move down" : "Move down",
     "Loading …" : "Inapakia",
     "Delete folder" : "Futa kisanduku",
     "Mark all as read" : "Mark all as read",
     "Rename" : "Ipe jina jipya",
+    "Move folder" : "Move folder",
     "Clear cache" : "Clear cache",
     "Subscribed" : "Iliyojisajili",
     "New message" : "Ujumbe mpya",
@@ -95,6 +99,7 @@ OC.L10N.register(
     "Draft" : "Draft",
     "Reply" : "Jibu",
     "Retry" : "Jaribu tene",
+    "Message" : "Message",
     "Copy to clipboard" : "Nakili kwenye ubao wa kunakili",
     "Add" : "Ongeza",
     "Show less" : "Show less",
