@@ -29,6 +29,7 @@ OC.L10N.register(
     "Search" : "ค้นหา",
     "Send" : "ส่ง",
     "Refresh" : "รีเฟรช",
+    "Ok" : "ตกลง",
     "Choose" : "เลือก",
     "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
     "Confirm" : "ยืนยัน",
@@ -36,6 +37,7 @@ OC.L10N.register(
     "Read" : "อ่าน",
     "Edit tags" : "แก้ไขแท็ก",
     "Back" : "ย้อนกลับ",
+    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
     "Description" : "คำอธิบาย",
     "Create" : "สร้าง",
     "Select" : "เลือก",
@@ -43,6 +45,10 @@ OC.L10N.register(
     "Accept" : "ยอมรับ",
     "Decline" : "ปฏิเสธ",
     "Remove" : "ลบออก",
+    "Today" : "วันนี้",
+    "Yesterday" : "เมื่อวาน",
+    "Last week" : "สัปดาห์ที่แล้ว",
+    "Last month" : "เดือนที่แล้ว",
     "Choose target folder" : "เลือกโฟลเดอร์เป้าหมาย",
     "Other" : "อื่น ๆ",
     "Forward" : "ส่งต่อ",
@@ -80,6 +86,9 @@ OC.L10N.register(
     "Valid until" : "ใช้ได้จนถึง",
     "Certificate" : "ใบรับรอง",
     "Submit" : "ส่ง",
+    "Group" : "กลุ่ม",
+    "Shared" : "ถูกแชร์",
+    "Shares" : "การแชร์",
     "Account connected" : "เชื่อมต่อบัญชีแล้ว",
     "All" : "ทั้งหมด",
     "Drafts" : "ฉบับร่าง",
@@ -93,7 +102,6 @@ OC.L10N.register(
     "Error loading message" : "เกิดข้อผิดพลาดขณะโหลดข้อความ",
     "Redirect" : "เปลี่ยนเส้นทาง",
     "The link leads to %s" : "ลิงก์จะนำไปยัง %s",
-    "Continue to %s" : "ดำเนินการต่อไปที่ %s",
-    "Actions" : "การกระทำ"
+    "Continue to %s" : "ดำเนินการต่อไปที่ %s"
 },
 "nplurals=1; plural=0;");
